# Table of Contents

- [objectives-and-transformations-items-v3](<./objectives-and-transformations-items-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: Objectives and Transformation Items (Projects) (Meta Model v3)](<./Modeling-Objectives-and-Transformation-Items-Projects-Meta-Model-v3.md>)
  - [Objectives](<./Modeling-Objectives-and-Transformation-Items-Projects-Meta-Model-v3/Objectives.md>)
  - [Projects](<./Modeling-Objectives-and-Transformation-Items-Projects-Meta-Model-v3/Projects.md>)
  - [Business Transformation Management (BTM) Logic](<./Modeling-Objectives-and-Transformation-Items-Projects-Meta-Model-v3/Business-Transformation-Management-BTM-Logic.md>)
  - [Example: Cloud migration with BTM](<./Modeling-Objectives-and-Transformation-Items-Projects-Meta-Model-v3/Example-Cloud-migration-with-BTM.md>)
